? my $app = shift;

      <ul>
        <li><span>Preferences</span></li>
        <li><span>Connections</span></li>
        <li><span>Help</span></li>
        <? if ($app->auth_enabled) { ?>
        <li class="separate-bottom"><a href="/logout">Logout</a></li>
        <? } ?>
      </ul>

