? my ($app, $window) = @_;
<li title="<?= $window->network ?>:<?= $window->title ?>" id="<?= $window->id ?>_tab" class="<?= $window->type ?>_tab<?= $window->disabled ? " disabled" : "" ?> visible">
  <div class="hit_area">
    <div class="tab_button" id="<?= $window->id ?>_tab_button"></div>
    <div style="float:left"><?= $window->pretty_name ?></div>
  </div>
</li>
