? my ($app, $window) = @_;

<div class="window<?= $window->{active} ? " active" : "" ?> <?= $window->type ?>" id="<?= $window->id ?>">
  <table border="0" cellpadding="0" cellspacing="0">
    <tr>
      <td valign="bottom">
        <ul class="messages" id="<?= $window->id ?>_messages">
